==> MouseAgingData_0.99.8.tar.gz: MouseAgingData/inst/doc/MouseAgingData_parabiosis_droplet.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----eval = FALSE-------------------------------------------------------------
#  # if(!requireNamespace("BiocManager", quietly = TRUE))
#      # install.packages("BiocManager")
#  # BiocManager::install("MouseAgingData")

## ----message = FALSE----------------------------------------------------------
library(scran)
library(scater)
library(ggplot2)
library(bluster)
library(SingleCellExperiment)
library(ExperimentHub)
library(MouseAgingData)

## -----------------------------------------------------------------------------
sce <- parabiosis10X()

## -----------------------------------------------------------------------------
# View the data
sce

## ----Data check---------------------------------------------------------------
# Sample metadata
head(colData(sce)) 

## -----------------------------------------------------------------------------
# Includes cell colors from the original paper
metadata(sce)

## ----subset sce---------------------------------------------------------------
sce_subset <- sce[, 1:1000]

## ----normalize----------------------------------------------------------------
set.seed(101000110)
clusters <- quickCluster(sce_subset)
sce_subset <- computeSumFactors(sce_subset, clusters=clusters)
sce_subset <- logNormCounts(sce_subset)

logcounts(sce_subset)[1:10, 1:10]

## ----feat select--------------------------------------------------------------
dec <- modelGeneVar(sce_subset)
hvg <- getTopHVGs(dec, prop=0.1)

## -----------------------------------------------------------------------------
head(rowData(sce))

## ----PCA, warning=FALSE-------------------------------------------------------
# Since we already have PCA coords from our authors, we will add these computed 
# PCA coords under a different name "osca_PCA"

set.seed(1234)
sce_subset <- runPCA(sce_subset, ncomponents=25, subset_row=hvg, 
                     name = "osca_PCA")


# Show the names of the elements in the ReducedDims slot
reducedDims(sce_subset)

## ----viewPCA, warning=FALSE---------------------------------------------------
reducedDim(sce_subset, "PCA")[1:5, 1:5]

## ----clustering---------------------------------------------------------------
colLabels(sce_subset) <- clusterCells(sce_subset, use.dimred='osca_PCA',
                               BLUSPARAM=NNGraphParam(cluster.fun="louvain"))

## ----fig.wide=TRUE------------------------------------------------------------

# Generate color map matching cell type to colors in publication
cell.color <- metadata(sce)$cell_color

gg <- plotUMAP(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----plot provided tSNE, fig.wide=TRUE----------------------------------------
gg <- plotTSNE(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----sesh info----------------------------------------------------------------
sessionInfo()

==> MouseAgingData_0.99.9.tar.gz: MouseAgingData/inst/doc/MouseAgingData_parabiosis_droplet.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL
)

## ----eval = FALSE-------------------------------------------------------------
#  # if(!requireNamespace("BiocManager", quietly = TRUE))
#      # install.packages("BiocManager")
#  # BiocManager::install("MouseAgingData")

## ----message = FALSE----------------------------------------------------------
library(scran)
library(scater)
library(ggplot2)
library(bluster)
library(SingleCellExperiment)
library(ExperimentHub)
library(MouseAgingData)

## -----------------------------------------------------------------------------
sce <- parabiosis10x()

## -----------------------------------------------------------------------------
# View the data
sce

## ----Data check---------------------------------------------------------------
# Sample metadata
head(colData(sce)) 

## -----------------------------------------------------------------------------
# Includes cell colors from the original paper
metadata(sce)

## ----subset sce---------------------------------------------------------------
sce_subset <- sce[, 1:1000]

## ----normalize----------------------------------------------------------------
set.seed(101000110)
clusters <- quickCluster(sce_subset)
sce_subset <- computeSumFactors(sce_subset, clusters=clusters)
sce_subset <- logNormCounts(sce_subset)

logcounts(sce_subset)[1:10, 1:10]

## ----feat select--------------------------------------------------------------
dec <- modelGeneVar(sce_subset)
hvg <- getTopHVGs(dec, prop=0.1)

## -----------------------------------------------------------------------------
head(rowData(sce))

## ----PCA, warning=FALSE-------------------------------------------------------
# Since we already have PCA coords from our authors, we will add these computed 
# PCA coords under a different name "osca_PCA"

set.seed(1234)
sce_subset <- runPCA(sce_subset, ncomponents=25, subset_row=hvg, 
                     name = "osca_PCA")


# Show the names of the elements in the ReducedDims slot
reducedDims(sce_subset)

## ----viewPCA, warning=FALSE---------------------------------------------------
reducedDim(sce_subset, "PCA")[1:5, 1:5]

## ----clustering---------------------------------------------------------------
colLabels(sce_subset) <- clusterCells(sce_subset, use.dimred='osca_PCA',
                               BLUSPARAM=NNGraphParam(cluster.fun="louvain"))

## ----fig.wide=TRUE------------------------------------------------------------

# Generate color map matching cell type to colors in publication
cell.color <- metadata(sce)$cell_color

gg <- plotUMAP(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----plot provided tSNE, fig.wide=TRUE----------------------------------------
gg <- plotTSNE(sce, color_by = "cell_type", text_by = "cell_type") 
gg + theme(legend.title=element_blank()) + 
    scale_color_manual(values=c(cell.color))

## ----sesh info----------------------------------------------------------------
sessionInfo()
